==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/igr-stacked-spline-area-series.js <==
import { __extends } from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedSplineAreaSeries } from "./StackedSplineAreaSeries";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent stacked spline area series.
*/
var IgrStackedSplineAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedSplineAreaSeries, _super);
    function IgrStackedSplineAreaSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedSplineAreaSeries.prototype.createImplementation = function () {
        return new StackedSplineAreaSeries();
    };
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "isSplineShapePartOfRange", {
        /**
         * Gets or sets whether to include the spline shape in the axis range requested of the axis.
        */
        get: function () {
            return this.i.abk;
        },
        set: function (v) {
            this.i.abk = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.es;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "isSpline", {
        /**
         * Gets whether the current series shows a spline shape.
        */
        get: function () {
            return this.i.fy;
        },
        enumerable: false,
        configurable: true
    });
    return IgrStackedSplineAreaSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedSplineAreaSeries };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/igr-stacked-spline-area-series.js <==
import { __extends } from "tslib";
import { IgrHorizontalStackedSeriesBase } from "./igr-horizontal-stacked-series-base";
import { StackedSplineAreaSeries } from "./StackedSplineAreaSeries";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent stacked spline area series.
*/
var IgrStackedSplineAreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrStackedSplineAreaSeries, _super);
    function IgrStackedSplineAreaSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrStackedSplineAreaSeries.prototype.createImplementation = function () {
        return new StackedSplineAreaSeries();
    };
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "isSplineShapePartOfRange", {
        /**
         * Gets or sets whether to include the spline shape in the axis range requested of the axis.
        */
        get: function () {
            return this.i.ab3;
        },
        set: function (v) {
            this.i.ab3 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.eu;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrStackedSplineAreaSeries.prototype, "isSpline", {
        /**
         * Gets whether the current series shows a spline shape.
        */
        get: function () {
            return this.i.f0;
        },
        enumerable: false,
        configurable: true
    });
    return IgrStackedSplineAreaSeries;
}(IgrHorizontalStackedSeriesBase));
export { IgrStackedSplineAreaSeries };
